@@ -1,12 +1,12 @@
-from langchain_core.messages import AIMessage, AnyMessage
+from langchain_core.messages import AIMessage
 
 
-def has_tool_calling(message: AnyMessage):
+def has_tool_calling(message: AIMessage):
     """Check if a message contains tool calls.
-    
+
     Args:
         message: Any message type to check for tool calls
-        
+
     Returns:
         bool: True if message is an AIMessage with tool calls, False otherwise
     """
@@ -16,4 +16,4 @@ def has_tool_calling(message: AnyMessage):
         and len(message.tool_calls) > 0
     ):
         return True
-    return False
\ No newline at end of file
+    return False
